Index: src/bp-friends/bp-friends-notifications.php
===================================================================
--- src/bp-friends/bp-friends-notifications.php	(revision 12467)
+++ src/bp-friends/bp-friends-notifications.php	(working copy)
@@ -79,19 +79,18 @@
 		 *
 		 * @since 1.0.0
 		 *
 		 * @param string|array $value       Depending on format, an HTML link to new requests profile
 		 *                                  tab or array with link and text.
 		 * @param int          $total_items The total number of messaging-related notifications
 		 *                                  waiting for the user.
 		 * @param int          $item_id     The primary item ID.
 		 */
-		$return = apply_filters( 'bp_friends_' . $amount . '_friendship_' . $action . '_notification', '<a href="' . esc_url( $link ) . '">' . esc_html( $text ) . '</a>', (int) $total_items, $item_id );
+		$return = apply_filters( 'bp_friends_' . $amount . '_friendship_' . $action . '_notification', '<a href="' . esc_url( $link ) . '">' . esc_html( $text ) . '</a>', (int) $total_items, $item_id, $secondary_item_id );
 	} else {
 		/** This filter is documented in bp-friends/bp-friends-notifications.php */
 		$return = apply_filters( 'bp_friends_' . $amount . '_friendship_' . $action . '_notification', array(
 			'link' => $link,
 			'text' => $text
-		), (int) $total_items, $item_id );
+		), (int) $total_items, $item_id, $secondary_item_id );
 	}
 
 	/**
@@ -79,19 +79,18 @@
 		 * @since 1.0.0
 		 *
-		 * @param string|array $value       Depending on format, an HTML link to new requests profile
-		 *                                  tab or array with link and text.
-		 * @param int          $total_items The total number of messaging-related notifications
-		 *                                  waiting for the user.
-		 * @param int          $item_id     The primary item ID.
+		 * @param string|array $value             Depending on format, an HTML link to new requests profile tab or array with link and text.
+		 * @param int          $total_items       The total number of messaging-related notifications waiting for the user.
+		 * @param int          $item_id           The primary item ID.
+		 * @param int          $secondary_item_id The secondary item ID.
 		 */
